==> slizzy-1.1.2.tar.gz: slizzy-1.1.2/src/slizzy/main.py <==
#!/usr/bin/env python3

import argparse
import enum
import sys

import slizzy.config as config
from slizzy.track      import Track
from slizzy.util       import color, logging, time


__all__ = [
  "module",
  "all_modules",
  "slizzy"
]


module = enum.Enum("modules", "slider zippy")
all_modules = { module.slider, module.zippy }



def slizzy(track, modules, download_tracks):
  logger = logging.Logger("slizzy")

  logger.log("Slizzy magic for track '" + track.title + "'", logging.level.info)
  logger.log("Query string: " + track.query_string, logging.level.info)
  logger.br()

  
  if not track.duration: # Duration not supplied from command line.
    try:
      from slizzy.google   import google
      from slizzy.beatport import beatport
      
      track.duration = next( # Extract duration from the first matching page.
        duration
        for page     in google(track, beatport.domain)
        for duration in [ beatport.get_metadata(track, page) ]
        if duration
      )
    except StopIteration:
      logger.log("Track duration unavailable", logging.level.error)
      sys.exit(3)
  
  
  if module.slider in modules:
    from slizzy.slider import slider
    
    slider_downloads = slider(track) if module.slider in modules else []
  else:
    slider_downloads = []
  
  
  if module.zippy in modules:
    from slizzy.zippy import zippy
    
    zippy_downloads = [
      dl
      for page in google(track, zippy.domain)
      for dl   in [ zippy.get_download(track, page) ]
      if dl
    ]
  else:
    zippy_downloads = []
  
  
  logger.log(
    "Selected " + color.result(len(slider_downloads)) + " slider entries.",
    logging.level.info
  )
  logger.log(
    "Selected " + color.result(len(zippy_downloads)) + " zippy entries.",
    logging.level.info
  )
  
  downloads = slider_downloads + zippy_downloads
  
  if not downloads:
    logger.log("No entries to download.")
    return
  
  if download_tracks:
    from slizzy.downloader import download
      
    download(downloads)
  else:
    logger.log("Selected urls:\n  " + "\n  ".join(
      download.name + " | " + download.link
      for download in downloads
    ))
  
  logger.br()
  logger.finish("Slizzied " + str(len(downloads)) + " tracks.")



def parse_args(argv):
  parser = argparse.ArgumentParser(
    description = "Slizzy is a tool to search for and "
                  "download slider.kz and zippyshare objects."
  )
  commands = parser.add_subparsers(dest = "command", help = "commands")

  dl  = commands.add_parser('dl',  help='download tracks')
  lns = commands.add_parser('lns', help='get download links')
  cfg = commands.add_parser('cfg', help='config')
  
  for command in [ dl, lns ]:
    command.add_argument(
      "tracks",
      help = "one or more tracks to seach, in the format: "
             "A & B ft. C - ID (D vs. E Remix)",
      nargs = '+'
    )
    command.add_argument(
      "-d", "--duration",
      help = "manually specify the track duration, eliding the beatport search"
    )
    command.add_argument(
      "--slider",
      action = "store_true",
      help = "search in slider.kz instead of all resources"
    )
    command.add_argument(
      "--zippy",
      action = "store_true",
      help = "search only in zippyshare instead of all resources"
    )
  
  cfg.add_argument("--google-key", help = "set the google API key")
  cfg.add_argument("--beatport-cx", help = "set the cx API key for the beatport search")
  cfg.add_argument("--zippyshare-cx", help = "set the cx API key for the zippyshare search")
  # add arguments for other settings, specially thresholds.


  args = parser.parse_args(argv)

  if args.command in [ "dl", "lns" ]:
    if args.duration:
      if len(args.tracks) > 1:
        print(
          "Error: with the duration parameter, only one track may be specified.",
          file = sys.stderr
        )
        sys.exit(1)
  
      try:
        args.duration = time.from_str(args.duration)
      except Exception as e:
        print("Error: " + str(e) + ".", file = sys.stderr)
        sys.exit(1)

  if args.command == "cfg":
    pass # validate args
  
  return args



def main(argv):
  args = parse_args(argv)
  
  if args.command in [ "dl", "lns" ]:
    for i, track in enumerate(args.tracks):
      try:
        args.tracks[i] = Track(track, args.duration)
      except:
        print("Error: invalid track format '" + track + "'.", file = sys.stderr)
        sys.exit(1)
    
    modules = {
      m
      for m, arg in [
        (module.slider, args.slider),
        (module.zippy,  args.zippy)
      ]
      if arg
    } or all_modules

    download_tracks = args.command == "dl"

    tracks = iter(args.tracks)
    
    try:
      slizzy(next(tracks), modules, download_tracks)
      
      for track in tracks:
        print(color.yellow(70 * "-"))
        slizzy(track, modules, download_tracks)
    except ConfigError as e:
      print("Error (config): " + str(e), file = sys.stderr)
      sys.exit(2)
  
  
  if args.command == "cfg":
    if args.google_key:
      config.cfg["google"]["key"] = args.google_key
      
    if args.beatport_cx:
      config.cfg["beatport"]["cx"] = args.beatport_cx

    if args.zippyshare_cx:
      config.cfg["zippyshare"]["cx"] = args.zippyshare_cx
    
    try:
      config.update(config.cfg)
    except ConfigError as e:
      print("Error (config): " + str(e), file = sys.stderr)
      sys.exit(2)



def cli():
  import signal
  
  def sigint(sig, frame):
    print() # Exit progress logging
    print("Slizzy: interrupted.", file = sys.stderr)
    sys.exit(130)

  signal.signal(signal.SIGINT, sigint)
  
  main(sys.argv[1:])

==> slizzy-1.1.3.tar.gz: slizzy-1.1.3/src/slizzy/main.py <==
#!/usr/bin/env python3

import argparse
import enum
import sys

import slizzy.config as config
from slizzy.track      import Track
from slizzy.util       import color, logging, time


__all__ = [
  "module",
  "all_modules",
  "slizzy"
]


module = enum.Enum("modules", "slider zippy")
all_modules = { module.slider, module.zippy }



def slizzy(track, modules, download_tracks):
  logger = logging.Logger("slizzy")

  logger.log("Slizzy magic for track '" + track.title + "'", logging.level.info)
  logger.log("Query string: " + track.query_string, logging.level.info)
  logger.br()

  
  if not track.duration: # Duration not supplied from command line.
    try:
      from slizzy.google   import google
      from slizzy.beatport import beatport
      
      track.duration = next( # Extract duration from the first matching page.
        duration
        for page     in google(track, beatport.domain)
        for duration in [ beatport.get_metadata(track, page) ]
        if duration
      )
    except StopIteration:
      logger.log("Track duration unavailable", logging.level.error)
      return
  
  
  if module.slider in modules:
    from slizzy.slider import slider
    
    slider_downloads = slider(track) if module.slider in modules else []
  else:
    slider_downloads = []
  
  
  if module.zippy in modules:
    from slizzy.zippy import zippy
    
    zippy_downloads = [
      dl
      for page in google(track, zippy.domain)
      for dl   in [ zippy.get_download(track, page) ]
      if dl
    ]
  else:
    zippy_downloads = []
  
  
  logger.log(
    "Selected " + color.result(len(slider_downloads)) + " slider entries.",
    logging.level.info
  )
  logger.log(
    "Selected " + color.result(len(zippy_downloads)) + " zippy entries.",
    logging.level.info
  )
  
  downloads = slider_downloads + zippy_downloads
  
  if not downloads:
    logger.log("No entries to download.")
    return
  
  if download_tracks:
    from slizzy.downloader import download
      
    download(downloads)
  else:
    logger.log("Selected urls:\n  " + "\n  ".join(
      download.name + " | " + download.link
      for download in downloads
    ))
  
  logger.br()
  logger.finish("Slizzied " + str(len(downloads)) + " tracks.")



def parse_args(argv):
  parser = argparse.ArgumentParser(
    description = "Slizzy is a tool to search for and "
                  "download slider.kz and zippyshare objects."
  )
  commands = parser.add_subparsers(dest = "command", help = "commands")

  dl  = commands.add_parser('dl',  help='download tracks')
  lns = commands.add_parser('lns', help='get download links')
  cfg = commands.add_parser('cfg', help='config')
  
  for command in [ dl, lns ]:
    command.add_argument(
      "tracks",
      help = "one or more tracks to seach, in the format: "
             "A & B ft. C - ID (D vs. E Remix)",
      nargs = '+'
    )
    command.add_argument(
      "-d", "--duration",
      help = "manually specify the track duration, eliding the beatport search"
    )
    command.add_argument(
      "--slider",
      action = "store_true",
      help = "search in slider.kz instead of all resources"
    )
    command.add_argument(
      "--zippy",
      action = "store_true",
      help = "search only in zippyshare instead of all resources"
    )
  
  cfg.add_argument("--google-key", help = "set the google API key")
  cfg.add_argument("--beatport-cx", help = "set the cx API key for the beatport search")
  cfg.add_argument("--zippyshare-cx", help = "set the cx API key for the zippyshare search")
  # add arguments for other settings, specially thresholds.


  args = parser.parse_args(argv)

  if args.command in [ "dl", "lns" ]:
    if args.duration:
      if len(args.tracks) > 1:
        print(
          "Error: with the duration parameter, only one track may be specified.",
          file = sys.stderr
        )
        sys.exit(1)
  
      try:
        args.duration = time.from_str(args.duration)
      except Exception as e:
        print("Error: " + str(e) + ".", file = sys.stderr)
        sys.exit(1)

  if args.command == "cfg":
    pass # validate args
  
  return args



def main(argv):
  args = parse_args(argv)
  
  if args.command in [ "dl", "lns" ]:
    for i, track in enumerate(args.tracks):
      try:
        args.tracks[i] = Track(track, args.duration)
      except:
        print("Error: invalid track format '" + track + "'.", file = sys.stderr)
        sys.exit(1)
    
    modules = {
      m
      for m, arg in [
        (module.slider, args.slider),
        (module.zippy,  args.zippy)
      ]
      if arg
    } or all_modules

    download_tracks = args.command == "dl"

    tracks = iter(args.tracks)
    
    try:
      slizzy(next(tracks), modules, download_tracks)
      
      for track in tracks:
        print(color.yellow(70 * "-"))
        slizzy(track, modules, download_tracks)
    except config.ConfigError as e:
      print("Error (config): " + str(e), file = sys.stderr)
      sys.exit(2)
  
  
  if args.command == "cfg":
    if args.google_key:
      config.cfg["google"]["key"] = args.google_key
      
    if args.beatport_cx:
      config.cfg["beatport"]["cx"] = args.beatport_cx

    if args.zippyshare_cx:
      config.cfg["zippyshare"]["cx"] = args.zippyshare_cx
    
    try:
      config.update(config.cfg)
    except config.ConfigError as e:
      print("Error (config): " + str(e), file = sys.stderr)
      sys.exit(2)



def cli():
  import signal
  
  def sigint(sig, frame):
    print() # Exit progress logging
    print("Slizzy: interrupted.", file = sys.stderr)
    sys.exit(130)

  signal.signal(signal.SIGINT, sigint)
  
  main(sys.argv[1:])
